==> easybuild-framework-4.6.1.tar.gz: easybuild-framework-4.6.1/easybuild/toolchains/fujitsu.py <==
##
# Copyright 2014-2022 Ghent University
#
# This file is part of EasyBuild,
# originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
# with support of Ghent University (http://ugent.be/hpc),
# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
# and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
#
# https://github.com/easybuilders/easybuild
#
# EasyBuild is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation v2.
#
# EasyBuild is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with EasyBuild.  If not, see <http://www.gnu.org/licenses/>.
##
"""
Fujitsu toolchain: Fujitsu compilers and MPI + Fujitsu SSL2 and Fujitsu FFTW

:author: Miguel Dias Costa (National University of Singapore)
"""
from easybuild.toolchains.ffmpi import Ffmpi
from easybuild.toolchains.fft.fujitsufftw import FujitsuFFTW
from easybuild.toolchains.linalg.fujitsussl import FujitsuSSL


class Fujitsu(Ffmpi, FujitsuFFTW, FujitsuSSL):
    """Compiler toolchain for Fujitsu."""
    NAME = 'Fujitsu'
    SUBTOOLCHAIN = Ffmpi.NAME

==> easybuild-framework-4.9.0.tar.gz: easybuild-framework-4.9.0/easybuild/toolchains/fujitsu.py <==
##
# Copyright 2014-2023 Ghent University
#
# This file is part of EasyBuild,
# originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
# with support of Ghent University (http://ugent.be/hpc),
# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
# and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
#
# https://github.com/easybuilders/easybuild
#
# EasyBuild is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation v2.
#
# EasyBuild is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with EasyBuild.  If not, see <http://www.gnu.org/licenses/>.
##
"""
Fujitsu toolchain: Fujitsu compilers and MPI + Fujitsu SSL2 and Fujitsu FFTW

Authors:

* Miguel Dias Costa (National University of Singapore)
"""
from easybuild.toolchains.ffmpi import Ffmpi
from easybuild.toolchains.fft.fujitsufftw import FujitsuFFTW
from easybuild.toolchains.linalg.fujitsussl import FujitsuSSL


class Fujitsu(Ffmpi, FujitsuFFTW, FujitsuSSL):
    """Compiler toolchain for Fujitsu."""
    NAME = 'Fujitsu'
    SUBTOOLCHAIN = Ffmpi.NAME
